REST framework JWT Auth
=======================

|build-status-image| |pypi-version|

**JSON Web Token Authentication support for Django REST Framework**

Full documentation for the project is available at `docs`_.

Overview
--------

This package provides `JSON Web Token Authentication`_ support for
`Django REST framework`_.

Requirements
------------

-  Python (3.8, 3.9, 3.10)
-  Django (3.2, 4.0)
-  Django REST Framework (3.13)

Installation
------------

Install using ``pip``\ ...

.. code:: bash

    $ pip install drf-auth-jwt

Documentation & Support
-----------------------

Full documentation for the project is available at `docs`_.

You may also want to follow the `author`_ on Twitter.

.. _docs: https://jovianorigin.github.io/drf-auth-jwt/
.. _JSON Web Token Authentication: http://tools.ietf.org/html/draft-ietf-oauth-json-web-token
.. _Django REST framework: http://django-rest-framework.org/
.. _Video: https://www.youtube.com/watch?v=825hodQ61bg
.. _JWT.io: http://jwt.io/
.. _author: https://twitter.com/lungeloSLX

.. |build-status-image| image:: https://github.com/JovianOrigin/drf-auth-jwt/actions/workflows/test.yml/badge.svg?branch=master
    :target: https://github.com/JovianOrigin/drf-auth-jwt/actions
.. |pypi-version| image:: https://img.shields.io/pypi/v/drf-auth-jwt.svg
    :target: https://pypi.python.org/pypi/drf-auth-jwt
